pub struct AuditQuery { /* private fields */ }Expand description
Builder for filtering audit events by time range, event type, actor, or resource.
Implementations
Sourceimpl AuditQuery
impl AuditQuery
pub fn new() -> Self
Sourcepub fn time_range(self, start: DateTime<Utc>, end: DateTime<Utc>) -> Self
pub fn time_range(self, start: DateTime<Utc>, end: DateTime<Utc>) -> Self
Filter events within a time range (inclusive).
Sourcepub fn matches(&self, event: &AuditEvent) -> bool
pub fn matches(&self, event: &AuditEvent) -> bool
Test whether an event matches this query.
Sourcepub fn filter<'a>(&self, events: &'a [AuditEvent]) -> Vec<&'a AuditEvent>
pub fn filter<'a>(&self, events: &'a [AuditEvent]) -> Vec<&'a AuditEvent>
Apply this query to a slice of events, returning matching events.